import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import javax.swing.AbstractButton;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JLabel;
import javax.swing.KeyStroke;
import javax.swing.JTextField;
import java.util.LinkedList;

public class PromptWindow implements ActionListener
{
    protected static JFrame frame;
    protected static JButton jbnOk;
    
    private LinkedList<JTextField> inputs = new LinkedList<JTextField>();
    private int[] args;

    private Macro macro;
    
    private static String OK = "Ok Pressed";
    
    private boolean fork = true;
    
    public PromptWindow(String[] labels, Macro m)
    {
	setUpWindow(labels, m, 0, null);
    }
    
    public PromptWindow(String[] labels, Macro m, int numArgs)
    {
	setUpWindow(labels, m, numArgs, null);
    }
    
    public PromptWindow(String[] labels, Macro m, int numArgs, int[] argDefaults)
    {
	setUpWindow(labels, m, numArgs, argDefaults);
    }
    
    private void setUpWindow(String[] labels, Macro m, int numArgs, int[] argDefaults)
    {
	JLabel label;
	JTextField text;
	int i;
	
	macro = m;
	args = new int[numArgs];
	
	JFrame.setDefaultLookAndFeelDecorated(true);
	// Create and set up the frame.
	frame = new JFrame("Prompt");
	frame.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
	
	// Create and set up the content pane.
	JPanel mainPane = new JPanel();
	if(labels != null) {
	    for(i=0; i<labels.length || i<numArgs; i++) {
		if(i<labels.length) {
		    label = new JLabel(labels[i]);
		    label.setHorizontalAlignment(JLabel.LEFT);
		    mainPane.add(label);
		}
		if(i<numArgs) {
		    String s;
		    if(argDefaults != null && i<argDefaults.length) {
			s = Integer.toString(argDefaults[i]);
		    } else {
			s = "0";
		    }
		    text = new JTextField(s, 4);
		    inputs.add(text);
		    //text.setActionCommand(Integer.toString(i));
		    //text.addActionListener(this);
		    mainPane.add(text);
		}
	    }
	}

	jbnOk = new JButton("Ok");
	jbnOk.setMnemonic(KeyEvent.VK_O);
	jbnOk.setActionCommand(OK);
	
	jbnOk.addActionListener(this);
	
	mainPane.add(jbnOk);
	
	mainPane.setOpaque(true);
	frame.getRootPane().setDefaultButton(jbnOk);
	frame.setContentPane(mainPane);
	
	// Display the window.
	frame.pack();
	frame.setVisible(true);
    }
    
    public void actionPerformed(ActionEvent e) {
	Thread t;
	int numArgs = inputs.size();
	int args[] = new int[numArgs];
	int i;
	
	if(e.getActionCommand().equals(OK)) {
	    for(i=0;i<numArgs;i++) {
		args[i] = Integer.parseInt(inputs.get(i).getText());
	    }
	    
	    macro.setArgs(args);
	    
	    frame.dispose();
	    
	    if(fork) {
		t = new Thread(macro);
		t.start();
	    } else {
		macro.run();
	    }
	}
    }
}
